from django.contrib import admin
from django.db.models import DateTimeField
from django.forms.widgets import SplitDateTimeWidget
from djangoats.oats.models import Worker
from djangoats.oats.models import PhoneMessage
from djangoats.oats.models import InOfficeComputer
from djangoats.oats.models import WorkOrder
from django.http import HttpResponseRedirect

def copy_workorder(old, new):
    new.name = old.name
    new.building = old.building
    new.room_number = old.room_number
    new.phone_number = old.phone_number
    new.problem = old.problem

def transfer(NewClass, queryset):
    queryset.update(status='C')
    for model in queryset:
        new_model = NewClass()
        copy_workorder(model, new_model)
        new_model.problem = "%s from %s:\n %s\n"  % (model._meta.verbose_name.title(), model.creation_time.strftime("%B %d, %Y, %I:%M %p"), model.problem)
        new_model.save()
    if queryset.count() == 1:
        return HttpResponseRedirect("/admin/%s/%s/%s/" % (new_model._meta.app_label, new_model._meta.module_name , new_model.pk))
    else:
        return HttpResponseRedirect("/admin/%s/%s/" % (new_model._meta.app_label, new_model._meta.module))

def phone_to_attendant(modeladmin, request, queryset):
    return transfer(InOfficeComputer, queryset)
phone_to_attendant.short_description = "Transfer to Attendant Computers"

def phone_to_workorder(modeladmin, request, queryset):
    return transfer(WorkOrder, queryset)
phone_to_workorder.short_description = "Transfer to Work Orders"

def workorder_to_attendant(modeladmin, request, queryset):
    return transfer(InOfficeComputer, queryset)
workorder_to_attendant.short_description = "Transfer to Attendant Computers"

def close(modeladmin, request, queryset):
    queryset.update(status='C')
close.short_description = "Close"

class WorkerAdmin(admin.ModelAdmin):
    list_display = ('display_name', 'first_name', 'last_name', 'phone_number')

class PhoneMessageAdmin(admin.ModelAdmin):
    fieldsets = (
        (None, {
            'fields': ('name', ('building', 'room_number'), 'phone_number', 'problem', 'comments', ('status','creation_time') )
        }),
    )
    list_display = ('name', 'building', 'room_number', 'phone_number', 'problem', 'comments', 'creation_time', 'status')
    list_filter = ['status']
    actions = [close, phone_to_attendant, phone_to_workorder]
    radio_fields = {"status": admin.VERTICAL}

class InOfficeComputerAdmin(admin.ModelAdmin):
    fieldsets = (
        (None, {
            'fields': (('name', 'privateid'), ('building', 'room_number'), 'phone_number', 'password', 'problem', 'resolution', 'status',('creation_time','close_time'), )
        }),
        ('Computer Description', {
            'fields': ('form_factor',('maker', 'model'), ('description', 'accessories'))
        }),
    )
    list_display = ('name', 'building', 'room_number', 'phone_number', 'problem', 'creation_time', 'status')
    list_filter = ['status']
    radio_fields = {"status": admin.HORIZONTAL}
    actions = [close]

class WorkOrderAdmin(admin.ModelAdmin):
    fieldsets = (
        (None, {
            'fields': ('name', ('building', 'room_number'), 'phone_number', 'problem', 'resolution', 'status', 'next_available_time',('creation_time','close_time'))
        }),
        ('Assigned Workers', {
            'classes': ('collapse',),
            'fields': ('workers',),
        }),
    )

    list_display = ('name', 'building', 'room_number', 'phone_number', 'problem', 'creation_time', 'status')
    list_filter = ['status', 'building']
    filter_horizontal = ['workers']
    radio_fields = {"status": admin.HORIZONTAL}
    actions = [close, workorder_to_attendant]

admin.site.register(Worker, WorkerAdmin)
admin.site.register(PhoneMessage, PhoneMessageAdmin)
admin.site.register(InOfficeComputer, InOfficeComputerAdmin)
admin.site.register(WorkOrder, WorkOrderAdmin)