from datetime import datetime
from datetime import timedelta
from datetime import time
from django.db import models
from djangoats.oats.buildings import BUILDING_CHOICES

class Worker(models.Model):
    display_name = models.CharField(max_length=1000, primary_key=True)
    first_name = models.CharField(max_length=1000)
    last_name = models.CharField(max_length=1000)
    phone_number = models.CharField(max_length=1000)
    def __unicode__(self): return self.display_name
    def get_absolute_url(self): return "/workers/%s" % self.display_name

class Ticket(models.Model):
    name = models.CharField(max_length=1000)
    creation_time = models.DateTimeField(default=datetime.now)
    close_time = models.DateTimeField(blank=True, null=True)
    building = models.CharField(max_length=1, choices=BUILDING_CHOICES, blank=True)
    room_number = models.CharField(max_length=1000, blank=True)
    phone_number = models.CharField(max_length=1000, blank=True)
    problem = models.TextField(blank=True,help_text="""
        <a href="#" id="toggle_formatting_help" style="position: relative; left: 360px; top: 2px;">formatting help</a>
        <table width="260px" id="formatting_help" style="display: none; position: relative; left: 287px; top: -6px;">
          <tr style="background-color: #D6FFA7; text-align: center">
            <td>
              <em>you type:</em>
            </td>
            <td>
              <em>you see:</em>
            </td>
          </tr>
          <tr>
            <td>
              *italics*
            </td>
            <td>
              <em>italics</em>
            </td>
          </tr>
          <tr>
            <td>
              **bold**
            </td>
            <td>
              <b>bold</b>
            </td>
          </tr>
          <tr>
            <td>
              `some.code()`
            </td>
            <td>
              <code>some.code()</code>
            </td>
          </tr>
          <tr>
            <td>
              * list item <br />
              * anutha
            </td>
            <td>
              <ul style="margin-left: 2em; padding-left: 0em;"><li style="padding-left: 0em;">list item</li><li style="padding-left: 0em;">anutha</li></ul>
            </td>
          </tr>
          <tr>
            <td>
              1. item one <br />
              2. item too
            </td>
            <td>
              <ol><li>item one</li><li>item too</li></ol>
            </td>
          </tr>
          <tr>
            <td>
              &lt;http://google.com/&gt;
            </td>
            <td>
              <a href="http://google.com">http://google.com/</a>
            </td>
          </tr>
          <tr>
            <td>
              [jfgi!](http://google.com)
            </td>
            <td>
              <a href="http://google.com">jfgi!</a>
            </td>
          </tr>
        </table>
    """)

    
    
    
    
    
    
    # I would hope there's a better way to do this.
    def get_specific(self):
        try:
            return self.workorder
        except:
            pass
        try:
            return self.inofficecomputer
        except:
            pass
        try:
            return self.phonemessage
        except:
            return self
    
    # If the Ticket just became closed, then
    # update the close_time of the Ticket.
    def update_close_time(self, before, after):
        if before.status != u'C' and after.status == u'C':
            after.close_time = datetime.now()
            after.save()
    
    # There may be a way to do this with signals
    def save(self):
        before = self.get_specific()
        super(Ticket, self).save()
        after = self.__class__.objects.get(pk=self.pk)
        self.update_close_time(before, after)

class WorkOrder(Ticket):
    STATUS_CHOICES = (
        (u'O', u'Open'),
        (u'C', u'Closed'),
        (u'2', u'2nd Level'),
        (u'A', u'Action Required'),
    )
    status = models.CharField(max_length=1, choices=STATUS_CHOICES, default="O")
    workers = models.ManyToManyField(Worker, blank=True)
    resolution = models.TextField(blank=True)
    next_available_time =  models.DateTimeField(default=datetime.now, blank=True)
    
    def priority(self):
        now = datetime.now()
        several_hours_before = self.next_available_time - timedelta(hours=2)
        an_hour_after = self.next_available_time + timedelta(hours=1)
        if self.workers.count() >= 1:
            # assigned
            return 4
        elif now < several_hours_before:
            # not upcoming
            return 3
        elif now < self.next_available_time:
            # upcoming
            return 2
        elif now < an_hour_after:
            # ready
            return 1
        else:
            # missed
            return 0
    def fuzzy_time(self, now=None):
        if not now:
            now = datetime.now()
        time_str = self.next_available_time.strftime("%I:%M %p")
        date_str = self.next_available_time.strftime("%b %d")
        weekday_str = self.next_available_time.strftime("%A")
        if self.next_available_time > now:
            # upcoming
            time_delta = self.next_available_time - now
            date_delta = self.next_available_time.date() - now.date()
            hours = time_delta.seconds / timedelta(hours=1).seconds
            if date_delta.days == 0:
                # it will become available later today
                if hours < 1:
                    return "Less than an hour (%s)" % time_str
                else:
                    return "In %s hour%s (%s)" % (hours, "" if hours == 1 else "s", time_str)
            elif date_delta.days == 1:
                # it will be available tomorrow
                return "Tomorrow (%s)" % date_str
            else:
                # it will be available in more than one day
                return "On %s (%s)" % (weekday_str, date_str)
        else:
            # it's ready
            time_delta = now - self.next_available_time
            date_delta = now.date() - self.next_available_time.date()
            hours = time_delta.seconds / timedelta(hours=1).seconds
            if date_delta.days == 0:
                # it became available earlier today
                if hours < 1:
                    return "Just now (%s)" % time_str
                else:
                    return "%s hour%s (%s) ago" % (hours, "" if hours == 1 else "s", time_str)
            elif date_delta.days == 1:
                # it became available yesterday
                return "Yesterday (%s)" % date_str
            else:
                # it will be available in more than one day
                return "Since %s (%s)" % (weekday_str, date_str)
    
    @models.permalink
    def get_absolute_url(self):
        return ('workorder_detail', (), { 'pk': self.pk})
    
class InOfficeComputer(Ticket):
    class Meta:
        verbose_name = "in-office computer"
    STATUS_CHOICES = (
        (u'O', u'In Office'),
        (u'P', u'Pending Pickup'),
        (u'C', u'Closed'),
        (u'A', u'Action Required'),
        (u'2', u'2nd Level'),
    )
    FORM_FACTOR_CHOICES = (
        (u'D', u'Desktop'),
        (u'L', u'Laptop'),
        (u'N', u'Netbook'),
        (u'H', u'Handheld'),
        (u'M', u'microATX'),
    )
    status = models.CharField(max_length=1, choices=STATUS_CHOICES, default="O")
    privateid = models.CharField(max_length=1000, blank=True, verbose_name="BearPass Login")
    password = models.CharField(max_length=1000, blank=True)
    resolution = models.TextField(blank=True)
    form_factor = models.CharField(max_length=1, choices=FORM_FACTOR_CHOICES, blank=True)
    maker = models.CharField(max_length=1000, blank=True)
    model = models.CharField(max_length=1000, blank=True)
    description = models.CharField(max_length=1000, blank=True)
    accessories = models.CharField(max_length=1000, blank=True)
    
    @models.permalink
    def get_absolute_url(self):
        return ('inoffice_detail', (), { 'pk': self.pk})
    
class PhoneMessage(Ticket):
    STATUS_CHOICES = (
        (u'O', u'Open'),
        (u'C', u'Closed'),
    )
    status = models.CharField(max_length=1, choices=STATUS_CHOICES, default="O")
    comments = models.TextField(blank=True)
    
    @models.permalink
    def get_absolute_url(self):
        return ('phone_detail', (), { 'pk': self.pk})
