from django.conf.urls.defaults import *
from djangoats.oats.models import Ticket
from djangoats.oats.models import PhoneMessage
from djangoats.oats.models import WorkOrder
from djangoats.oats.models import InOfficeComputer
from djangoats.oats.models import Worker

obj_list_view = 'django.views.generic.list_detail.object_list'

contacts_dict = {
    'queryset': Worker.objects.all(),
    'template_name': 'oats/contacts.html',
}

urlpatterns = patterns('',
    # The following lines are for the different ticket detail pages:
    url(r'^phone/(?P<pk>\d+)$', 'djangoats.oats.views.phone_view', name="phone_detail"),
    url(r'^workorder/(?P<pk>\d+)$', 'djangoats.oats.views.workorder_view', name="workorder_detail"),
    url(r'^inoffice/(?P<pk>\d+)$', 'djangoats.oats.views.inoffice_view', name="inoffice_detail"),
    # The following lines are for the sidebar filters:
    url(r'^phone/$', obj_list_view, {'queryset': PhoneMessage.objects.all(), 'template_name': 'oats/phone_list.html', 'extra_context': {'title': 'All Phone Messages'}}, name="phone_all"),
    url(r'^phone/open/$', obj_list_view, {'queryset': PhoneMessage.objects.filter(status='O'), 'template_name': 'oats/phone_list.html', 'extra_context': {'title': 'Open Phone Messages'}}, name="phone_open"),
    url(r'^workorder/$', obj_list_view, {'queryset': WorkOrder.objects.all(), 'template_name': 'oats/workorder_list.html', 'extra_context': {'title': 'All Work Orders'}}, name="workorder_all"),
    url(r'^workorder/open/$', obj_list_view, {'queryset': WorkOrder.objects.filter(status='O'), 'template_name': 'oats/workorder_list.html', 'extra_context': {'title': 'Open Work Orders'}}, name="workorder_open"),
    url(r'^workorder/2ndlevel/$', obj_list_view, {'queryset': WorkOrder.objects.filter(status='2'), 'template_name': 'oats/workorder_list.html', 'extra_context': {'title': '2nd Level Work Orders'}}, name="workorder_2ndlevel"),
    url(r'^workorder/actionrequired/$', obj_list_view, {'queryset': WorkOrder.objects.filter(status='A'), 'template_name': 'oats/workorder_list.html', 'extra_context': {'title': 'Action Required Work Orders'}}, name="workorder_actionrequired"),
    url(r'^inoffice/$', obj_list_view, {'queryset': InOfficeComputer.objects.all(), 'template_name': 'oats/inoffice_list.html', 'extra_context': {'title': 'All In-Office Computers'}}, name="inoffice_all"),
    url(r'^inoffice/open/$', obj_list_view, {'queryset': InOfficeComputer.objects.filter(status='O'), 'template_name': 'oats/inoffice_list.html', 'extra_context': {'title': 'Open In-Office Computers'}}, name="inoffice_open"),
    url(r'^inoffice/pickup/$', obj_list_view, {'queryset': InOfficeComputer.objects.filter(status='P'), 'template_name': 'oats/inoffice_list.html', 'extra_context': {'title': 'Pending Pickup'}}, name="inoffice_pickup"),
    url(r'^inoffice/2ndlevel/$', obj_list_view, {'queryset': InOfficeComputer.objects.filter(status='2'), 'template_name': 'oats/inoffice_list.html', 'extra_context': {'title': '2nd Level In-Office Computers'}}, name="inoffice_2ndlevel"),
    url(r'^inoffice/actionrequired/$', obj_list_view, {'queryset': InOfficeComputer.objects.filter(status='A'), 'template_name': 'oats/inoffice_list.html', 'extra_context': {'title': 'Action Required In-Office Computers'}}, name="inoffice_actionrequired"),
    # The following lines are for creating new tickets:
    url(r'^phone/new$', 'djangoats.oats.views.phone_view', name="phone_new"),
    url(r'^workorder/new$', 'djangoats.oats.views.workorder_view', name="workorder_new"),
    url(r'^inoffice/new$', 'djangoats.oats.views.inoffice_view', name="inoffice_new"),
    # 
    url(r'^workers/$', 'djangoats.oats.views.workers', name="worker_all"),
    url(r'^workers/(?P<name>.*)', 'djangoats.oats.views.worker', name="worker_detail"),
    # Contacts page:
    url(r'^contacts/$', 'django.views.generic.list_detail.object_list', contacts_dict, name="contacts"),
    # Kiosk:
    url(r'^kiosk/$', 'djangoats.oats.views.kiosk_view', name="kiosk"),
    # Root:
    url(r'^$', 'djangoats.oats.views.index', name="grits_index"),
)