import logging
from django.contrib import messages
from django.core.context_processors import csrf
from djangoats.oats.models import Worker
from djangoats.oats.models import WorkOrder
from djangoats.oats.models import PhoneMessage
from djangoats.oats.models import InOfficeComputer
from djangoats.oats.models import Ticket
from djangoats.oats.forms import *
from django.shortcuts import render_to_response
from django.http import HttpResponse, HttpResponseRedirect
from django.contrib.admin.helpers import AdminForm
from django.contrib.admin import site
from django.template import RequestContext

def index(request):
    workorder_list = list(WorkOrder.objects.filter(status=u"O"))
    workorder_list = sorted(workorder_list, key=WorkOrder.priority)
    return render_to_response('oats/ticket_list.html', {
        'inoffice_list': InOfficeComputer.objects.filter(status=u"O"),
        'workorder_list': workorder_list,
        'phone_count': PhoneMessage.objects.filter(status=u"O").count()
        }, context_instance=RequestContext(request))

def workers(request):
    worker_list = Worker.objects.all().extra(order_by = ['last_name'])
    return render_to_response('oats/workers.html', {'worker_list': worker_list}, context_instance=RequestContext(request))

    
def worker(request, name):
    worker = Worker.objects.get(display_name=name)
    workorder_list = WorkOrder.objects.filter(workers=worker).exclude(status="C")
    return render_to_response('oats/worker.html', {'worker': worker, 'object_list': workorder_list}, context_instance=RequestContext(request))

def ticket_view(model_class):
    def view(request, pk=None):
        if not pk:
            obj = model_class()
        else:
            obj = model_class.objects.get(pk=pk)
        form_class = make_modelform_class(model_class)
        if request.method == 'POST':
            form = form_class(data=request.POST, instance=obj)
            if form.is_valid():
                form.save()
                logging.debug("Form is valid.")
                messages.success(request, 'Successfully updated Ticket.')
                return HttpResponseRedirect(reverse('grits_index'))
            else:
                logging.debug("Form is invalid.")
                logging.debug("Form errors: %s" % str(form.errors))
        else:
            form = form_class(instance=obj)
        adminform = AdminForm(form, site._registry[model_class].fieldsets, {})
        context = {'obj': obj, 'form': form, 'adminform': adminform, 'opts': model_class._meta}
        context.update(csrf(request))
        return render_to_response('oats/ticket_detail.html', context, context_instance=RequestContext(request))
    return view
    
def kiosk_view(request):
    class KioskForm(ModelForm):
        class Meta:
            model = InOfficeComputer
            exclude = ['close_time', 'creation_time', 'problem', 'status', 
                        'resolution', 'maker', 'model', 'description', 'accessories']
    if request.method == 'POST':
        form = KioskForm(data=request.POST)
        if form.is_valid():
            form.save()
            messages.success(request, 'Your information has been successfully saved.')
            return HttpResponseRedirect(reverse('kiosk'))
        else:
            logging.debug("Form is invalid.")
            logging.debug("Form errors: %s" % str(form.errors))
    else:
        form = KioskForm()
        return render_to_response('oats/kiosk.html', {'form': form}, context_instance=RequestContext(request))
    

phone_view = ticket_view(PhoneMessage)
workorder_view = ticket_view(WorkOrder)
inoffice_view = ticket_view(InOfficeComputer)
